@@ -1,15 +1,13 @@
 package DBIx::dbMan::Extension::CmdStandardSQL;
 
 use strict;
-use vars qw/$VERSION @ISA/;
-use DBIx::dbMan::Extension;
+use base 'DBIx::dbMan::Extension';
 
-$VERSION = '0.10';
-@ISA = qw/DBIx::dbMan::Extension/;
+our $VERSION = '0.11';
 
 1;
 
-sub IDENTIFICATION { return "000001-000013-000010"; }
+sub IDENTIFICATION { return "000001-000013-000011"; }
 
 sub preference { return 1000; }
 
@@ -19,7 +17,7 @@ sub handle_action {
 	my ($obj,%action) = @_;
 
 	if ($action{action} eq 'COMMAND') {
-		if ($action{cmd} =~ /^(?:\/\*.*?\*\/\s*)?(select|explain)\s+/i) {
+		if ($action{cmd} =~ /^(?:\/\*.*?\*\/\s*)?(select|with|explain)\s+/i) {
 			$action{action} = 'SQL';
 			$action{type} = 'select';
 			$action{sql} = $action{cmd};
