@@ -4,11 +4,11 @@ use strict;
 use base 'DBIx::dbMan::Extension';
 use Text::FormatTable;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 1;
 
-sub IDENTIFICATION { return "000001-000045-000004"; }
+sub IDENTIFICATION { return "000001-000045-000005"; }
 
 sub preference { return 50; }
 
@@ -24,17 +24,30 @@ sub handle_action {
 			$obj->{-interface}->error("No current connection selected.");
 			return %action;
 		}
+		my $lastwhat = $action{what};
+		my $schema = '';
+		$schema = uc $1 if $action{what} =~ s/^([^.]+)\.//;
+		my $schema_add = '';
+		my @schema = ();
+		if ($schema) {
+			$schema_add = ' AND owner = ?';
+			push @schema,$schema;
+		}
+		my $basetable = $schema?'all':'user';
+
 		my $d = $obj->{-dbi}->selectall_arrayref(q!
 			SELECT object_name, object_type
-			FROM user_objects
-			WHERE UPPER(object_name) LIKE ? AND object_type !.($action{type}?(q! = '!.uc($action{type}).q!'!):q!IN ('PROCEDURE','FUNCTION','TRIGGER','VIEW','PACKAGE','PACKAGE BODY')!),
-			{},uc($action{what}));
+			FROM !.$basetable.q!_objects
+			WHERE UPPER(object_name) LIKE ? AND object_type !.($action{type}?(q! = '!.uc($action{type}).q!'!):q!IN ('PROCEDURE','FUNCTION','TRIGGER','VIEW','PACKAGE','PACKAGE BODY')!).$schema_add,
+			{},uc($action{what}),@schema);
+		$action{what} = $lastwhat;
 		if (defined $d) {
 			$action{action} = 'NONE';
 			if (@$d) {
 				if (@$d == 1) {
 					$action{action} = 'EDIT';
 					$action{what} = $d->[0][0];
+					$action{what} = "$schema.".$action{what} if $schema;
 					$action{type} = $d->[0][1];
 					delete $action{processed};
 					return %action;
@@ -43,9 +56,15 @@ sub handle_action {
 					$action{output} = "You must explicit say which object you want edit:\n";
 					my $tab = new Text::FormatTable '| l | l |';
 					$tab->rule;
-					$tab->head('NAME','TYPE');
+					my @schema = ();
+					push @schema,'SCHEMA' if $schema;
+					$tab->head(@schema,'NAME','TYPE');
 					$tab->rule;
-					for (@$d) { $tab->row(@$_); }
+					for (@$d) {
+						my @item = ();
+						push @item,$schema if $schema;
+						$tab->row(@item,@$_);
+					}
 					$tab->rule;
 					$action{output} .= $tab->render($obj->{-interface}->render_size);
 				}
@@ -53,8 +72,9 @@ sub handle_action {
 				$obj->{-interface}->error("Object ".$action{what}." not found.");
 				return %action;
 			}
+		} else {
+			print DBI::errstr()."\n";
 		}
-			
 	}
 
 	return %action;
